"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.main = void 0;
const typescript_estree_1 = require("@typescript-eslint/typescript-estree");
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const analyze_1 = require("./analyze");
const config_1 = require("./config");
const constants_1 = require("./constants");
const write_1 = require("./write");
let diagramWidth = 0;
let diagramHeight = 0;
const defaultLineColumn = { line: 1, column: 1 };
const main = async (fileName, config) => {
    try {
        if (!path_1.default.isAbsolute(fileName)) {
            fileName = path_1.default.resolve(path_1.default.resolve(), fileName);
        }
        const aliasForViteConfig = await (0, config_1.loadVite)();
        if (aliasForViteConfig) {
            if (!config.alias) {
                config.alias = aliasForViteConfig;
            }
        }
        const finalConfig = (0, config_1.resolveFinalConfig)(config);
        const title = path_1.default.basename(fileName).replace(/\.[^/.]+$/, '');
        const parentNode = {
            id: title,
            code: '',
            title,
            astType: typescript_estree_1.AST_NODE_TYPES.ImportSpecifier,
            fileName,
            disableDrag: false,
            exportName: '',
            coordinates: [0, 0],
            children: [],
            exists: true,
            loc: {
                start: { ...defaultLineColumn },
                end: { ...defaultLineColumn },
            },
        };
        (0, analyze_1.analyze)(true, finalConfig.alias, fileName, parentNode, path_1.default.dirname(fileName));
        const x = constants_1.NODE_MARGIN, y = constants_1.NODE_MARGIN;
        const { id, content, code } = parentNode;
        const nodes = [
            {
                id,
                content,
                coordinates: [x, y],
                data: {
                    code,
                    title: id,
                    fileName,
                    loc: {
                        start: { ...defaultLineColumn },
                        end: { ...defaultLineColumn },
                    },
                },
            },
        ];
        const links = [];
        convertToFinalNode(parentNode, nodes, links, x, y + constants_1.NEXT_NODE_POSITION_Y);
        const diagram = {
            vscode: finalConfig.vscode,
            width: diagramWidth + constants_1.NEXT_NODE_POSITION_X,
            height: diagramHeight + constants_1.NEXT_NODE_POSITION_Y,
            schema: {
                nodes,
                links,
            },
        };
        (0, write_1.writeHtml)(diagram);
    }
    catch (e) {
        console.log(chalk_1.default.red(`e: ${e}`));
    }
    finally {
        process.exit();
    }
};
exports.main = main;
const convertToFinalNode = (parentNode, nodes, links, x, y) => {
    const { children } = parentNode;
    for (const child of children) {
        const { id, code, content, disableDrag, exists, loc, fileName } = child;
        if (exists) {
            const findedNode = nodes.find((node) => node.id === id);
            if (!findedNode) {
                x += constants_1.NEXT_NODE_POSITION_X;
                if (diagramWidth < x) {
                    diagramWidth = x;
                }
                if (diagramHeight < y) {
                    diagramHeight = y;
                }
                nodes.push({
                    id,
                    content,
                    disableDrag,
                    coordinates: [x, y],
                    data: { code, title: id, fileName, loc },
                });
                x = convertToFinalNode(child, nodes, links, x, y + constants_1.NEXT_NODE_POSITION_Y);
            }
            links.push({ input: parentNode.id, output: id });
        }
    }
    return x;
};
